@@ -38,9 +38,9 @@
 
 #define LIBOFX_MAJOR_VERSION 0
 #define LIBOFX_MINOR_VERSION 9
-#define LIBOFX_MICRO_VERSION 5
+#define LIBOFX_MICRO_VERSION 11
 #define LIBOFX_BUILD_VERSION 0
-#define LIBOFX_VERSION_RELEASE_STRING "0.9.5"
+#define LIBOFX_VERSION_RELEASE_STRING "0.9.11"
 
 #ifdef IN_LIBOFX
 #  include "config.h"
@@ -77,7 +77,7 @@ extern "C" {
 #define OFX_ACCOUNT_ID_LENGTH (OFX_BANKID_LENGTH + OFX_BRANCHID_LENGTH + OFX_ACCTID_LENGTH + 1)
 #define OFX_ACCOUNT_NAME_LENGTH        255
 #define OFX_MARKETING_INFO_LENGTH      (360 + 1)
-#define OFX_TRANSACTION_NAME_LENGTH    (32 + 1)
+#define OFX_TRANSACTION_NAME_LENGTH    (96 + 1)
 #define OFX_UNIQUE_ID_LENGTH           (32 + 1)
 #define OFX_UNIQUE_ID_TYPE_LENGTH      (10 + 1)
 #define OFX_SECNAME_LENGTH             (32 + 1)
@@ -90,6 +90,7 @@ extern "C" {
 #define OFX_APPID_LENGTH               (32)
 #define OFX_APPVER_LENGTH              (32)
 #define OFX_HEADERVERSION_LENGTH       (32)
+#define OFX_CLIENTUID_LENGTH           (36 + 1)
 
   /*
   #define OFX_STATEMENT_CB               0;
@@ -811,6 +812,7 @@ extern "C" {
     char header_version[OFX_HEADERVERSION_LENGTH];
     char appid[OFX_APPID_LENGTH];
     char appver[OFX_APPVER_LENGTH];
+    char clientuid[OFX_CLIENTUID_LENGTH];
   };
 
 #define OFX_AMOUNT_LENGTH (32 + 1)
